==> haskell-attoparsec-iso8601-1.0.1.0-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec-iso8601
version: 1.0.1.0
id: attoparsec-iso8601-1.0.1.0-3psXVkbPM97GRGfBeP1f9U
key: attoparsec-iso8601-1.0.1.0-3psXVkbPM97GRGfBeP1f9U
license: BSD-3-Clause
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Parsing of ISO 8601 dates, originally from aeson.
description:
    Parsing of ISO 8601 dates, originally from aeson.
category: Parsing
abi: 2963ebe12672edebc85494f88a4a2735
exposed: True
exposed-modules:
    Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/attoparsec-iso8601-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/attoparsec-iso8601-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/attoparsec-iso8601-1.0.1.0
hs-libraries: HSattoparsec-iso8601-1.0.1.0-3psXVkbPM97GRGfBeP1f9U
depends:
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr text-1.2.3.1 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock
haddock-html: /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-iso8601-1.0.1.0-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec-iso8601
version: 1.0.1.0
id: attoparsec-iso8601-1.0.1.0-7CbArQaTyAXUzFYdJqSmh
key: attoparsec-iso8601-1.0.1.0-7CbArQaTyAXUzFYdJqSmh
license: BSD-3-Clause
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Parsing of ISO 8601 dates, originally from aeson.
description:
    Parsing of ISO 8601 dates, originally from aeson.
category: Parsing
abi: 9e0f69475ff20fbac512367e3abcdb69
exposed: True
exposed-modules:
    Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/attoparsec-iso8601-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/attoparsec-iso8601-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/attoparsec-iso8601-1.0.1.0
hs-libraries: HSattoparsec-iso8601-1.0.1.0-7CbArQaTyAXUzFYdJqSmh
depends:
    attoparsec-0.13.2.3-G0AWAouFPeyAsmzjnpc0yX base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr text-1.2.3.1 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock
haddock-html: /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
